;=====================================================================
;                           PV-WAVE ARL
;
;                 PV-Wave Advanced Rendering Library
;                        11/90   D. Carr
;
;             (c) Copyright Precision Visuals, Inc., 1990
;                     Boulder, Colorado, U.S.A.
;
;                        All Rights Reserved.
;
;  This software is confidential information which is proprietary to
;  and a trade secret of Precision Visuals, Inc. Use, duplication or
;  disclosure is subject to the terms of an appropriate license
;  agreement.
;  ------------------------------------------------------------------
;  Use, duplication, or disclosure by the Government is subject to
;  restrictions set forth in paragraph (b)(3)(B) of the Rights in
;  Technical Data and Computer Software clause in DAR 7-104.9(a).
;
;  Contractor : Precision Visuals, Inc., Boulder, Colorado, U.S.A.
;  -------------------------------------------------------------------
;
;  Program Overview : PROCEDURE Img_True8
;
;  Img_True8 generates a pseudo true color image suitable for display
;  on devices capable of displaying 256 simultaneous colors.
;
;  MANDATORY INPUTS :
;
;  red_img :        A 2 dimensional image representing the red
;                   component of a true color image.   red_img
;                   must be the same size as grn_img and blu_img.
;
;  grn_img :        A 2 dimensional image representing the green
;                   component of a true color image.
;
;  blu_img :        A 2 dimensional image representing the blue
;                   component of a true color image.
;
;  rgb_img :        On input, rgb_img may be undefined.   On return,
;                   rgb_img is a pseudo true color 8-bit image that
;                   can be displayed using the "Tv" command.
;                   NOTE : For correct appearance, rgb_img should
;                          be displayed in a PV-WAVE window with 256
;                          colors allocated to it.   Also, the
;                          proper colortable needs to be loaded by
;                          using :
;                                   Tvlct, red, grn, blu, 0
;                          Where red, grn, and blu are the values
;                          obtained from Img_True8 .
;
;  red :            On input, red may be undefined.   On return,
;                   red contains the red component of the colortable.
;
;  grn :            On input, grn may be undefined.   On return,
;                   grn contains the green component.
;
;  blu :            On input, blu may be undefined.   On return,
;                   blu contains the blue component.
;
;=====================================================================
;
PRO Img_True8, red_img, grn_img, blu_img, rgb_img, red, grn, blu

sr = Size(red_img)
sg = Size(grn_img)
sb = Size(blu_img)

IF (sr(0) NE 2) THEN BEGIN
   Print, "Red image must be 2 dimensional."
   STOP
ENDIF
IF (sg(0) NE 2) THEN BEGIN
   Print, "Green image must be 2 dimensional."
   STOP
ENDIF
IF (sb(0) NE 2) THEN BEGIN
   Print, "Blue image must be 2 dimensional."
   STOP
ENDIF
IF ((((sr(1) NE sg(1)) OR (sg(1) NE sb(1))) OR (sb(1) NE sr(1))) OR $
    (((sr(2) NE sg(2)) OR (sg(2) NE sb(2))) OR (sb(2) NE sr(2)))) THEN BEGIN
   Print, "Red, green, and blue images are not the same size."
   STOP
ENDIF

rgb_img = Bytarr(sr(1), sr(2))

red_img = Bytscl(red_img, Top=7)
grn_img = Bytscl(grn_img, Top=7)
blu_img = Bytscl(blu_img, Top=3)

red = Intarr(8, 8, 4)
grn = Intarr(8, 8, 4)
blu = Intarr(8, 8, 4)
FOR i=0, 7 DO red(i, *, *) = i
FOR i=0, 7 DO grn(*, i, *) = i
FOR i=0, 3 DO blu(*, *, i) = i
red = Bytscl(red)
grn = Bytscl(grn)
blu = Bytscl(blu)
 
rgb_img = (red_img) + (8 * grn_img) + (8 * 8 * blu_img)
 
RETURN
END
