;=====================================================================
;                           PV-WAVE ARL
;
;                 PV-Wave Advanced Rendering Library
;                        11/90   D. Carr
;
;             (c) Copyright Precision Visuals, Inc., 1990
;                     Boulder, Colorado, U.S.A.
;
;                        All Rights Reserved.
;
;  This software is confidential information which is proprietary to
;  and a trade secret of Precision Visuals, Inc. Use, duplication or
;  disclosure is subject to the terms of an appropriate license
;  agreement.
;  ------------------------------------------------------------------
;  Use, duplication, or disclosure by the Government is subject to
;  restrictions set forth in paragraph (b)(3)(B) of the Rights in
;  Technical Data and Computer Software clause in DAR 7-104.9(a).
;
;  Contractor : Precision Visuals, Inc., Boulder, Colorado, U.S.A.
;  -------------------------------------------------------------------
;
;  Program Overview : FUNCTION Poly_C_Conv
;
;  Poly_C_Conv returns a list of colors (one color for each polygon)
;  given a polygon_list and a list of colors for each vertex.
;  The "Shade_Volume" function returns a list of polygon colors when
;  the "shades" keyword is used.   This list has one color per VERTEX.
;  The "Poly_Plot" function, however, requires a color list with one
;  color per POLYGON.   Poly_C_Conv is useful for converting a vertex
;  based list to a polygon based list.
;
;  SEE ALSO :  Shade_Volume  Polyshade  Poly_Plot
;
;  MANDATORY INPUTS :
;
;  polygon_list :   An array containing a polygon list.   See the
;                   documentation for the "Polyshade" and "Poly_Plot"
;                   functions for more information about
;                   polygon lists.
;
;  colors :         A vertex based color list.
;
;=====================================================================
;
FUNCTION Poly_C_Conv, polygon_list, colors

IF (N_Elements(polygon_list) LT 2) THEN BEGIN
   Print, "Invalid polygon_list."
   STOP
ENDIF

IF ((Max(polygon_list) GE N_Elements(colors)) OR (Min(polygon_list) LT 0)) THEN BEGIN
   Print, "Invalid polygon list."
   STOP
ENDIF
 
L1 = Long(1)
pg_num = Poly_Count(polygon_list)
colors_p = Intarr(pg_num)

sl = N_Elements(polygon_list)
poly_pt = 0
col_pt = 0
WHILE (poly_pt LT sl) DO BEGIN
   colors_p(col_pt) = AVG(colors(polygon_list(poly_pt+L1:poly_pt+polygon_list(poly_pt))))
   poly_pt = poly_pt + polygon_list(poly_pt) + L1
   col_pt = col_pt + L1
ENDWHILE
 
RETURN, colors_p
END
