;=====================================================================
;                           PV-WAVE ARL
;
;                 PV-Wave Advanced Rendering Library
;                        11/90   D. Carr
;
;             (c) Copyright Precision Visuals, Inc., 1990
;                     Boulder, Colorado, U.S.A.
;
;                        All Rights Reserved.
;
;  This software is confidential information which is proprietary to
;  and a trade secret of Precision Visuals, Inc. Use, duplication or
;  disclosure is subject to the terms of an appropriate license
;  agreement.
;  ------------------------------------------------------------------
;  Use, duplication, or disclosure by the Government is subject to
;  restrictions set forth in paragraph (b)(3)(B) of the Rights in
;  Technical Data and Computer Software clause in DAR 7-104.9(a).
;
;  Contractor : Precision Visuals, Inc., Boulder, Colorado, U.S.A.
;  -------------------------------------------------------------------
;
;  Program Overview : FUNCTION Poly_Dev
;
;  Poly_Dev returns a list of 3-D points converted from NORMAL to
;  DEVICE coordinates.   The returned list is in LONG integer form.
;
;  SEE ALSO :  Poly_Norm  Poly_Trans
;
;  MANDATORY INPUTS :
;
;  points :         A (3, n) array of points (or verticies) to
;                   transform.
;
;  winx :           The maximum X dimension in DEVICE coordinates.
;                   Usually, this is set to the X size of the current
;                   PV-WAVE window.
;
;  winy :           The maximum Y dimension in DEVICE coordinates.
;                   Usually, this is set to the Y size of the current
;                   PV-WAVE window.
;
;=====================================================================
;
FUNCTION Poly_Dev, points, winx, winy

sz = Size(points)
IF (sz(0) NE 2) THEN BEGIN
   Print, "Invalid points array."
   STOP
ENDIF
IF (sz(1) NE 3) THEN BEGIN
   Print, "Invalid points array."
   STOP
ENDIF

points(0, *) = points(0, *) * Float(winx(0))
points(1, *) = points(1, *) * Float(winy(0))
points(2, *) = points(2, *) * Float(Max([winx(0), winy(0)]))

RETURN, points
END
