;=====================================================================
;                           PV-WAVE ARL
;
;                 PV-Wave Advanced Rendering Library
;                        11/90   D. Carr
;
;             (c) Copyright Precision Visuals, Inc., 1990
;                     Boulder, Colorado, U.S.A.
;
;                        All Rights Reserved.
;
;  This software is confidential information which is proprietary to
;  and a trade secret of Precision Visuals, Inc. Use, duplication or
;  disclosure is subject to the terms of an appropriate license
;  agreement.
;  ------------------------------------------------------------------
;  Use, duplication, or disclosure by the Government is subject to
;  restrictions set forth in paragraph (b)(3)(B) of the Rights in
;  Technical Data and Computer Software clause in DAR 7-104.9(a).
;
;  Contractor : Precision Visuals, Inc., Boulder, Colorado, U.S.A.
;  -------------------------------------------------------------------
;
;  Program Overview : PROCEDURE Poly_Sphere
;  Poly_Sphere generates a vertex_list and a polygon_list that
;  represent a sphere.   This vertex_list and polygon_list are
;  suitable for use with the "Polyshade" and "Poly_Plot" functions.
;
;  SEE ALSO :  Grid_Sphere
;
;  MANDATORY INPUTS :
;
;  radius :         If radius is a scalar value, then all the polygons
;                   will be generated at this radius.   If radius is
;                   a 2-D (m, n) array, then the radius of each
;                   polygon will be generated at the corresponding
;                   radius.   The radius array is scaled to the
;                   dimensions (px, py) before use.
;
;  px :             A scalar value specifying the number of polygons
;                   around the equator.
;
;  py :             A scalar value specifying the number of polygons
;                   around the meridian.
;
;  vertex_list :    On input, vertex_list may be undefined.   On
;                   return, it contains a (3, n) array of polygon
;                   verticies.
;
;  polygon_list :   On input, polygon_list may be undefined.   On
;                   return, it contains the list of verticies for
;                   each polygon.
;
;=====================================================================
;
PRO Poly_Sphere, radius, px, py, vertex_list, polygon_list

IF ((px LT 3) OR (py LT 3)) THEN BEGIN
   Print, "px and py must be > = 3"
   STOP
ENDIF

sr = Size(radius)
IF (sr(0) NE 2) THEN BEGIN
   rad = Fltarr(2, 2)
   rad(*, *) = radius(0)
ENDIF ELSE BEGIN
   rad = radius
ENDELSE
rad = Congrid(rad, px, py, /Interp)

Poly_Surf, rad, vertex_list, polygon_list, pg_num

vertex_list(0, *) = vertex_list(0, *) * 2.0 * !PI / Float(px - 1)
vertex_list(1, *) = (vertex_list(1, *) * !PI / Float(py - 1)) - (!PI / 2.0)
vertex_list(*, *) = Conv_To_Rect(vertex_list(0, *), vertex_list(1, *), $
                                 vertex_list(2, *))

RETURN
END
