;=====================================================================
;                           PV-WAVE ARL
;
;                 PV-Wave Advanced Rendering Library
;                        11/90   D. Carr
;
;             (c) Copyright Precision Visuals, Inc., 1990
;                     Boulder, Colorado, U.S.A.
;
;                        All Rights Reserved.
;
;  This software is confidential information which is proprietary to
;  and a trade secret of Precision Visuals, Inc. Use, duplication or
;  disclosure is subject to the terms of an appropriate license
;  agreement.
;  ------------------------------------------------------------------
;  Use, duplication, or disclosure by the Government is subject to
;  restrictions set forth in paragraph (b)(3)(B) of the Rights in
;  Technical Data and Computer Software clause in DAR 7-104.9(a).
;
;  Contractor : Precision Visuals, Inc., Boulder, Colorado, U.S.A.
;  -------------------------------------------------------------------
;
;  Program Overview : PROCEDURE Poly_Surf
;
;  Given an 2-D array containing Z values, Poly_Surf generates a
;  3-D vertex_list and a polygon_list suitable for input into the
;  "Polyshade" or "Poly_Plot" routines.
;
;  MANDATORY INPUTS :
;
;  surf_dat :       A 2 dimensional array containing Z values.
;                   The 3-D polygon verticies are generated from
;                   this data.
;
;  vertex_list :    On input, vertex_list may be undefined.
;                   On return, vertex_list is a (3, n) array
;                   containing the 3-D coordinates of the polygon
;                   verticies.   This array is suitable for input
;                   into "Poly_Trans", "Poly_Norm", "Poly_Dev",
;                   "Poly_Plot", and "Polyshade".   See the
;                   documentation on "Poly_Plot" and "Polyshade"
;                   for more information about vertex_list.
;
;  polygon_list :   On input, polygon_list may be undefined.
;                   On return, vertex_list is a one dimensional
;                   array containing the number of sides for each
;                   polygon as well as the subscripts into the
;                   vertex_list array for the verticies of each
;                   polygon.   All the polygons generated by
;                   Poly_Surf have four sides (and four verticies).
;                   This array is suitable for input into "Poly_Plot"
;                   and "Polyshade".   See the documentation on
;                   "Poly_Plot" and "Polyshade" for more information
;                   about polygon_list.
;
;  pg_num :         On input, pg_num may be undefined.   On return,
;                   pg_num is the total number of polygons defined
;                   by vertex_list and polygon_list.   pg_num can be
;                   used as input into "Poly_Plot".
;
;=====================================================================
;
PRO Poly_Surf, surf_dat, vertex_list, polygon_list, pg_num

L0 = Long(0)
L1 = Long(1)
L2 = Long(2)
L3 = Long(3)
L4 = Long(4)
L5 = Long(5)
 
sz = Size(surf_dat)
IF (sz(0) NE 2) THEN BEGIN
   Print, "surf_dat array not 2 dimensional."
   STOP
ENDIF

datx = sz(1)
daty = sz(2)

vertex_list = Fltarr(L3, (datx * daty), /Nozero)
vertex_map = Lindgen(datx, daty)
temp1 = Findgen(datx)
temp2 = Replicate(1.0, daty)
temp = temp1 # temp2

vertex_list(0, *) = temp(*)
vertex_list(1, *) = Float(Fix(Float(vertex_map(*)) / Float(datx)))
vertex_list(2, *) = surf_dat(*)
 
pg_num = (datx - L1) * (daty - L1)
 
polygon_list = Lonarr((pg_num * L5), /Nozero)
 
list_index = Lindgen(pg_num) * L5
polygon_list(list_index) = L4
 
list_index = list_index + L1
polygon_list(list_index) = vertex_map(L0:datx-L2, L0:daty-L2)
list_index = list_index + L1
polygon_list(list_index) = vertex_map(L1:datx-L1, L0:daty-L2)
list_index = list_index + L1
polygon_list(list_index) = vertex_map(L1:datx-L1, L1:daty-L1)
list_index = list_index + L1
polygon_list(list_index) = vertex_map(L0:datx-L2, L1:daty-L1)
 
RETURN
END
