;=====================================================================
;                           PV-WAVE ARL
;
;                 PV-Wave Advanced Rendering Library
;                        11/90   D. Carr
;
;             (c) Copyright Precision Visuals, Inc., 1990
;                     Boulder, Colorado, U.S.A.
;
;                        All Rights Reserved.
;
;  This software is confidential information which is proprietary to
;  and a trade secret of Precision Visuals, Inc. Use, duplication or
;  disclosure is subject to the terms of an appropriate license
;  agreement.
;  ------------------------------------------------------------------
;  Use, duplication, or disclosure by the Government is subject to
;  restrictions set forth in paragraph (b)(3)(B) of the Rights in
;  Technical Data and Computer Software clause in DAR 7-104.9(a).
;
;  Contractor : Precision Visuals, Inc., Boulder, Colorado, U.S.A.
;  -------------------------------------------------------------------
;
;  Program Overview : FUNCTION Poly_Trans
;
;  Poly_Trans returns a list of 3-D points transformed by a 4x4
;  transformation matrix.
;
;  SEE ALSO :  Poly_Dev  Poly_Norm
;
;  MANDATORY INPUTS :
;
;  points :         A (3, n) array of points (or verticies) to
;                   transform.
;
;  trans :          A (4, 4) array to transform the points with.
;
;=====================================================================
;
FUNCTION Poly_Trans, points, trans

sz = Long(Size(points))

IF (sz(0) NE 2) THEN BEGIN
   Print, "Invalid points array."
   STOP
ENDIF
IF (sz(1) NE 3) THEN BEGIN
   Print, "Invalid points array."
   STOP
ENDIF

szt = Size(trans)
IF (szt(0) NE 2) THEN BEGIN
   Print, "Invalid transformation matrix."
   STOP
ENDIF
IF ((szt(1) NE 4) OR (szt(2) NE 4)) THEN BEGIN
   Print, "Transformation matrix not 4x4."
   STOP
ENDIF

limit = 10000.0

xx = Fltarr(sz(2), /Nozero)
yy = Fltarr(sz(2), /Nozero)
zz = Fltarr(sz(2), /Nozero)
un = Fltarr(sz(2), /Nozero)

un(*) = 1.0
xx(*) = points(0, *)
yy(*) = points(1, *)
zz(*) = points(2, *)

vec = Fltarr(sz(2), 4)
tvec = ([[xx(*)], [yy(*)], [zz(*)], [un(*)]])

vec(*, *) = tvec # trans
points(0, *) = (vec(*, 0) * limit) / ABS(vec(*, 3) * limit)
points(1, *) = (vec(*, 1) * limit) / ABS(vec(*, 3) * limit)
points(2, *) = (vec(*, 2) * limit) / ABS(vec(*, 3) * limit)

RETURN, points
END
