;=====================================================================
;                           PV-WAVE ARL
;
;                 PV-Wave Advanced Rendering Library
;                        11/90   D. Carr
;
;             (c) Copyright Precision Visuals, Inc., 1990
;                     Boulder, Colorado, U.S.A.
;
;                        All Rights Reserved.
;
;  This software is confidential information which is proprietary to
;  and a trade secret of Precision Visuals, Inc. Use, duplication or
;  disclosure is subject to the terms of an appropriate license
;  agreement.
;  ------------------------------------------------------------------
;  Use, duplication, or disclosure by the Government is subject to
;  restrictions set forth in paragraph (b)(3)(B) of the Rights in
;  Technical Data and Computer Software clause in DAR 7-104.9(a).
;
;  Contractor : Precision Visuals, Inc., Boulder, Colorado, U.S.A.
;  -------------------------------------------------------------------
;
;  Program Overview : PROCEDURE Vol_Pad
;  Vol_Pad returns a 3 dimensional volume of data padded on all six
;  sides with zeroes.
;  For best results, process volumes with Vol_Pad before transforming
;  them with "Vol_Trans".
;
;  SEE ALSO :  Vol_Trans
;
;  MANDATORY INPUTS :
;
;  volume :         On input, this is the 3 dimensional volume of data
;                   to pad.   On return, this is the padded volume.
;
;  pad_width :      The width of the padding around the volume.
;                   The size of the volume will increase by
;                   (2 * pad_width) in all 3 dimensions.
;                   If pad_width is zero, then no padding will be
;                   performed.   However, the DATA to NORMAL
;                   coordinate conversion factors will still be
;                   generated.
;
;=====================================================================
;
FUNCTION Vol_Pad, volume, pad_width

sv = Size(volume)
IF (sv(0) NE 3) THEN BEGIN
   Print, "Volume array not 3 dimensional."
   STOP
ENDIF
pad_width = Fix(pad_width(0))

IF (pad_width GE 1) THEN BEGIN
   imgx = sv(1) + (2 * pad_width)
   imgy = sv(2) + (2 * pad_width)
   imgz = sv(3) + (2 * pad_width)
   vol1 = Rebin(Reform(volume(0:0, 0:0, 0:0), 1, 1, 1), imgx, imgy, imgz)
   vol1(*, *, *) = 0
   vol1(pad_width:pad_width+sv(1)-1, pad_width:pad_width+sv(2)-1, $
        pad_width:pad_width+sv(3)-1) = volume(*,*,*)
ENDIF

RETURN, vol1
END
